@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class TMMISConfig(AppConfig):
-    name = 'tmmis'
+    name = "tmmis"
