@@ -1,6 +1,6 @@
 from collections import namedtuple
 from enum import Enum
-from typing import Tuple, Any
+from typing import Any, Tuple
 
 from django.db import connections
 
