@@ -28,7 +28,7 @@ class AtfFileInfo(BaseModel):
         default="00000000-0000-0000-0000-000000000000",
     )
     file_type = models.ForeignKey("AtfFileType", db_column="rf_FileTypeID", **FK_DEFAULT)
-    lpu = models.ForeignKey("OmsLpu", to_field="uuid", db_column="rf_LPUGuid", max_length=36, **FK_DEFAULT)
+    lpu = models.ForeignKey("OmsLpu", to_field="uuid", db_column="rf_LPUGuid", **FK_DEFAULT)
     lpu_type = models.CharField(db_column="rf_LPUTypeGuid", max_length=36)
 
     flags = models.IntegerField(db_column="Flags", default=0)
