@@ -1,5 +1,5 @@
 # noinspection PyUnresolvedReferences
-from uuid import uuid4, UUID
+from uuid import UUID, uuid4
 
 from django.db import models
 
