@@ -38,7 +38,7 @@ class HltMkab(BaseModel):
     cod_person = models.CharField(db_column="COD_Person", max_length=20)
     military_cod = models.CharField(db_column="MilitaryCOD", max_length=3)
     uchastok = models.ForeignKey("HltUchastok", models.DO_NOTHING, db_column="rf_UchastokID")
-    citizen_id = models.IntegerField(db_column="rf_CitizenID")
+    citizen = models.ForeignKey("HltCitizen", db_column="rf_CitizenID", **FK_DEFAULT)
     type_doc = models.ForeignKey("OmsTypedoc", models.DO_NOTHING, db_column="rf_TYPEDOCID")
     s_doc = models.CharField(db_column="S_DOC", max_length=10)
     n_doc = models.CharField(db_column="N_DOC", max_length=15)
