@@ -25,8 +25,10 @@ class HltMkbTap(BaseModel):
     guid = models.CharField(db_column="GUID", max_length=36, default=uuid4)
     date = models.DateTimeField(db_column="Date", default=datetime.date(1900, 1, 1))
     clinical_diagnos = models.CharField(db_column="ClinicalDiagnos", max_length=2000, default="")
-    is_final = models.BooleanField(db_column="IsFinal", default=False)
-    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
+
+    # Эти поля есть в схеме БД Белгородской МИС, но нет, к примеру, в Челябинске
+    # is_final = models.BooleanField(db_column="IsFinal", default=False)
+    # doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
 
     class Meta:
         managed = False
